Class: Aws::Comprehend::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Comprehend::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-comprehend/client.rb,
sig/client.rbs
Overview
An API client for Comprehend. To construct a client, you need to configure a :region and :credentials.
client = Aws::Comprehend::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchDetectDominantLanguageResponseSuccess, _BatchDetectEntitiesResponseSuccess, _BatchDetectKeyPhrasesResponseSuccess, _BatchDetectSentimentResponseSuccess, _BatchDetectSyntaxResponseSuccess, _BatchDetectTargetedSentimentResponseSuccess, _ClassifyDocumentResponseSuccess, _ContainsPiiEntitiesResponseSuccess, _CreateDatasetResponseSuccess, _CreateDocumentClassifierResponseSuccess, _CreateEndpointResponseSuccess, _CreateEntityRecognizerResponseSuccess, _CreateFlywheelResponseSuccess, _DeleteDocumentClassifierResponseSuccess, _DeleteEndpointResponseSuccess, _DeleteEntityRecognizerResponseSuccess, _DeleteFlywheelResponseSuccess, _DeleteResourcePolicyResponseSuccess, _DescribeDatasetResponseSuccess, _DescribeDocumentClassificationJobResponseSuccess, _DescribeDocumentClassifierResponseSuccess, _DescribeDominantLanguageDetectionJobResponseSuccess, _DescribeEndpointResponseSuccess, _DescribeEntitiesDetectionJobResponseSuccess, _DescribeEntityRecognizerResponseSuccess, _DescribeEventsDetectionJobResponseSuccess, _DescribeFlywheelIterationResponseSuccess, _DescribeFlywheelResponseSuccess, _DescribeKeyPhrasesDetectionJobResponseSuccess, _DescribePiiEntitiesDetectionJobResponseSuccess, _DescribeResourcePolicyResponseSuccess, _DescribeSentimentDetectionJobResponseSuccess, _DescribeTargetedSentimentDetectionJobResponseSuccess, _DescribeTopicsDetectionJobResponseSuccess, _DetectDominantLanguageResponseSuccess, _DetectEntitiesResponseSuccess, _DetectKeyPhrasesResponseSuccess, _DetectPiiEntitiesResponseSuccess, _DetectSentimentResponseSuccess, _DetectSyntaxResponseSuccess, _DetectTargetedSentimentResponseSuccess, _DetectToxicContentResponseSuccess, _ImportModelResponseSuccess, _ListDatasetsResponseSuccess, _ListDocumentClassificationJobsResponseSuccess, _ListDocumentClassifierSummariesResponseSuccess, _ListDocumentClassifiersResponseSuccess, _ListDominantLanguageDetectionJobsResponseSuccess, _ListEndpointsResponseSuccess, _ListEntitiesDetectionJobsResponseSuccess, _ListEntityRecognizerSummariesResponseSuccess, _ListEntityRecognizersResponseSuccess, _ListEventsDetectionJobsResponseSuccess, _ListFlywheelIterationHistoryResponseSuccess, _ListFlywheelsResponseSuccess, _ListKeyPhrasesDetectionJobsResponseSuccess, _ListPiiEntitiesDetectionJobsResponseSuccess, _ListSentimentDetectionJobsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTargetedSentimentDetectionJobsResponseSuccess, _ListTopicsDetectionJobsResponseSuccess, _PutResourcePolicyResponseSuccess, _StartDocumentClassificationJobResponseSuccess, _StartDominantLanguageDetectionJobResponseSuccess, _StartEntitiesDetectionJobResponseSuccess, _StartEventsDetectionJobResponseSuccess, _StartFlywheelIterationResponseSuccess, _StartKeyPhrasesDetectionJobResponseSuccess, _StartPiiEntitiesDetectionJobResponseSuccess, _StartSentimentDetectionJobResponseSuccess, _StartTargetedSentimentDetectionJobResponseSuccess, _StartTopicsDetectionJobResponseSuccess, _StopDominantLanguageDetectionJobResponseSuccess, _StopEntitiesDetectionJobResponseSuccess, _StopEventsDetectionJobResponseSuccess, _StopKeyPhrasesDetectionJobResponseSuccess, _StopPiiEntitiesDetectionJobResponseSuccess, _StopSentimentDetectionJobResponseSuccess, _StopTargetedSentimentDetectionJobResponseSuccess, _StopTrainingDocumentClassifierResponseSuccess, _StopTrainingEntityRecognizerResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateEndpointResponseSuccess, _UpdateFlywheelResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_detect_dominant_language(params = {}) ⇒ Types::BatchDetectDominantLanguageResponse
Determines the dominant language of the input text for a batch of documents.
-
#batch_detect_entities(params = {}) ⇒ Types::BatchDetectEntitiesResponse
Inspects the text of a batch of documents for named entities and returns information about them.
-
#batch_detect_key_phrases(params = {}) ⇒ Types::BatchDetectKeyPhrasesResponse
Detects the key noun phrases found in a batch of documents.
-
#batch_detect_sentiment(params = {}) ⇒ Types::BatchDetectSentimentResponse
Inspects a batch of documents and returns an inference of the prevailing sentiment,
POSITIVE,NEUTRAL,MIXED, orNEGATIVE, in each one. -
#batch_detect_syntax(params = {}) ⇒ Types::BatchDetectSyntaxResponse
Inspects the text of a batch of documents for the syntax and part of speech of the words in the document and returns information about them.
-
#batch_detect_targeted_sentiment(params = {}) ⇒ Types::BatchDetectTargetedSentimentResponse
Inspects a batch of documents and returns a sentiment analysis for each entity identified in the documents.
-
#classify_document(params = {}) ⇒ Types::ClassifyDocumentResponse
Creates a classification request to analyze a single document in real-time.
-
#contains_pii_entities(params = {}) ⇒ Types::ContainsPiiEntitiesResponse
Analyzes input text for the presence of personally identifiable information (PII) and returns the labels of identified PII entity types such as name, address, bank account number, or phone number.
-
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a dataset to upload training or test data for a model associated with a flywheel.
-
#create_document_classifier(params = {}) ⇒ Types::CreateDocumentClassifierResponse
Creates a new document classifier that you can use to categorize documents.
-
#create_endpoint(params = {}) ⇒ Types::CreateEndpointResponse
Creates a model-specific endpoint for synchronous inference for a previously trained custom model For information about endpoints, see [Managing endpoints][1].
-
#create_entity_recognizer(params = {}) ⇒ Types::CreateEntityRecognizerResponse
Creates an entity recognizer using submitted files.
-
#create_flywheel(params = {}) ⇒ Types::CreateFlywheelResponse
A flywheel is an Amazon Web Services resource that orchestrates the ongoing training of a model for custom classification or custom entity recognition.
-
#delete_document_classifier(params = {}) ⇒ Struct
Deletes a previously created document classifier.
-
#delete_endpoint(params = {}) ⇒ Struct
Deletes a model-specific endpoint for a previously-trained custom model.
-
#delete_entity_recognizer(params = {}) ⇒ Struct
Deletes an entity recognizer.
-
#delete_flywheel(params = {}) ⇒ Struct
Deletes a flywheel.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy that is attached to a custom model.
-
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns information about the dataset that you specify.
-
#describe_document_classification_job(params = {}) ⇒ Types::DescribeDocumentClassificationJobResponse
Gets the properties associated with a document classification job.
-
#describe_document_classifier(params = {}) ⇒ Types::DescribeDocumentClassifierResponse
Gets the properties associated with a document classifier.
-
#describe_dominant_language_detection_job(params = {}) ⇒ Types::DescribeDominantLanguageDetectionJobResponse
Gets the properties associated with a dominant language detection job.
-
#describe_endpoint(params = {}) ⇒ Types::DescribeEndpointResponse
Gets the properties associated with a specific endpoint.
-
#describe_entities_detection_job(params = {}) ⇒ Types::DescribeEntitiesDetectionJobResponse
Gets the properties associated with an entities detection job.
-
#describe_entity_recognizer(params = {}) ⇒ Types::DescribeEntityRecognizerResponse
Provides details about an entity recognizer including status, S3 buckets containing training data, recognizer metadata, metrics, and so on.
-
#describe_events_detection_job(params = {}) ⇒ Types::DescribeEventsDetectionJobResponse
Gets the status and details of an events detection job.
-
#describe_flywheel(params = {}) ⇒ Types::DescribeFlywheelResponse
Provides configuration information about the flywheel.
-
#describe_flywheel_iteration(params = {}) ⇒ Types::DescribeFlywheelIterationResponse
Retrieve the configuration properties of a flywheel iteration.
-
#describe_key_phrases_detection_job(params = {}) ⇒ Types::DescribeKeyPhrasesDetectionJobResponse
Gets the properties associated with a key phrases detection job.
-
#describe_pii_entities_detection_job(params = {}) ⇒ Types::DescribePiiEntitiesDetectionJobResponse
Gets the properties associated with a PII entities detection job.
-
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Gets the details of a resource-based policy that is attached to a custom model, including the JSON body of the policy.
-
#describe_sentiment_detection_job(params = {}) ⇒ Types::DescribeSentimentDetectionJobResponse
Gets the properties associated with a sentiment detection job.
-
#describe_targeted_sentiment_detection_job(params = {}) ⇒ Types::DescribeTargetedSentimentDetectionJobResponse
Gets the properties associated with a targeted sentiment detection job.
-
#describe_topics_detection_job(params = {}) ⇒ Types::DescribeTopicsDetectionJobResponse
Gets the properties associated with a topic detection job.
-
#detect_dominant_language(params = {}) ⇒ Types::DetectDominantLanguageResponse
Determines the dominant language of the input text.
-
#detect_entities(params = {}) ⇒ Types::DetectEntitiesResponse
Detects named entities in input text when you use the pre-trained model.
-
#detect_key_phrases(params = {}) ⇒ Types::DetectKeyPhrasesResponse
Detects the key noun phrases found in the text.
-
#detect_pii_entities(params = {}) ⇒ Types::DetectPiiEntitiesResponse
Inspects the input text for entities that contain personally identifiable information (PII) and returns information about them.
-
#detect_sentiment(params = {}) ⇒ Types::DetectSentimentResponse
Inspects text and returns an inference of the prevailing sentiment (
POSITIVE,NEUTRAL,MIXED, orNEGATIVE). -
#detect_syntax(params = {}) ⇒ Types::DetectSyntaxResponse
Inspects text for syntax and the part of speech of words in the document.
-
#detect_targeted_sentiment(params = {}) ⇒ Types::DetectTargetedSentimentResponse
Inspects the input text and returns a sentiment analysis for each entity identified in the text.
-
#detect_toxic_content(params = {}) ⇒ Types::DetectToxicContentResponse
Performs toxicity analysis on the list of text strings that you provide as input.
-
#import_model(params = {}) ⇒ Types::ImportModelResponse
Creates a new custom model that replicates a source custom model that you import.
-
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
List the datasets that you have configured in this Region.
-
#list_document_classification_jobs(params = {}) ⇒ Types::ListDocumentClassificationJobsResponse
Gets a list of the documentation classification jobs that you have submitted.
-
#list_document_classifier_summaries(params = {}) ⇒ Types::ListDocumentClassifierSummariesResponse
Gets a list of summaries of the document classifiers that you have created.
-
#list_document_classifiers(params = {}) ⇒ Types::ListDocumentClassifiersResponse
Gets a list of the document classifiers that you have created.
-
#list_dominant_language_detection_jobs(params = {}) ⇒ Types::ListDominantLanguageDetectionJobsResponse
Gets a list of the dominant language detection jobs that you have submitted.
-
#list_endpoints(params = {}) ⇒ Types::ListEndpointsResponse
Gets a list of all existing endpoints that you've created.
-
#list_entities_detection_jobs(params = {}) ⇒ Types::ListEntitiesDetectionJobsResponse
Gets a list of the entity detection jobs that you have submitted.
-
#list_entity_recognizer_summaries(params = {}) ⇒ Types::ListEntityRecognizerSummariesResponse
Gets a list of summaries for the entity recognizers that you have created.
-
#list_entity_recognizers(params = {}) ⇒ Types::ListEntityRecognizersResponse
Gets a list of the properties of all entity recognizers that you created, including recognizers currently in training.
-
#list_events_detection_jobs(params = {}) ⇒ Types::ListEventsDetectionJobsResponse
Gets a list of the events detection jobs that you have submitted.
-
#list_flywheel_iteration_history(params = {}) ⇒ Types::ListFlywheelIterationHistoryResponse
Information about the history of a flywheel iteration.
-
#list_flywheels(params = {}) ⇒ Types::ListFlywheelsResponse
Gets a list of the flywheels that you have created.
-
#list_key_phrases_detection_jobs(params = {}) ⇒ Types::ListKeyPhrasesDetectionJobsResponse
Get a list of key phrase detection jobs that you have submitted.
-
#list_pii_entities_detection_jobs(params = {}) ⇒ Types::ListPiiEntitiesDetectionJobsResponse
Gets a list of the PII entity detection jobs that you have submitted.
-
#list_sentiment_detection_jobs(params = {}) ⇒ Types::ListSentimentDetectionJobsResponse
Gets a list of sentiment detection jobs that you have submitted.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a given Amazon Comprehend resource.
-
#list_targeted_sentiment_detection_jobs(params = {}) ⇒ Types::ListTargetedSentimentDetectionJobsResponse
Gets a list of targeted sentiment detection jobs that you have submitted.
-
#list_topics_detection_jobs(params = {}) ⇒ Types::ListTopicsDetectionJobsResponse
Gets a list of the topic detection jobs that you have submitted.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Attaches a resource-based policy to a custom model.
-
#start_document_classification_job(params = {}) ⇒ Types::StartDocumentClassificationJobResponse
Starts an asynchronous document classification job using a custom classification model.
-
#start_dominant_language_detection_job(params = {}) ⇒ Types::StartDominantLanguageDetectionJobResponse
Starts an asynchronous dominant language detection job for a collection of documents.
-
#start_entities_detection_job(params = {}) ⇒ Types::StartEntitiesDetectionJobResponse
Starts an asynchronous entity detection job for a collection of documents.
-
#start_events_detection_job(params = {}) ⇒ Types::StartEventsDetectionJobResponse
Starts an asynchronous event detection job for a collection of documents.
-
#start_flywheel_iteration(params = {}) ⇒ Types::StartFlywheelIterationResponse
Start the flywheel iteration.This operation uses any new datasets to train a new model version.
-
#start_key_phrases_detection_job(params = {}) ⇒ Types::StartKeyPhrasesDetectionJobResponse
Starts an asynchronous key phrase detection job for a collection of documents.
-
#start_pii_entities_detection_job(params = {}) ⇒ Types::StartPiiEntitiesDetectionJobResponse
Starts an asynchronous PII entity detection job for a collection of documents.
-
#start_sentiment_detection_job(params = {}) ⇒ Types::StartSentimentDetectionJobResponse
Starts an asynchronous sentiment detection job for a collection of documents.
-
#start_targeted_sentiment_detection_job(params = {}) ⇒ Types::StartTargetedSentimentDetectionJobResponse
Starts an asynchronous targeted sentiment detection job for a collection of documents.
-
#start_topics_detection_job(params = {}) ⇒ Types::StartTopicsDetectionJobResponse
Starts an asynchronous topic detection job.
-
#stop_dominant_language_detection_job(params = {}) ⇒ Types::StopDominantLanguageDetectionJobResponse
Stops a dominant language detection job in progress.
-
#stop_entities_detection_job(params = {}) ⇒ Types::StopEntitiesDetectionJobResponse
Stops an entities detection job in progress.
-
#stop_events_detection_job(params = {}) ⇒ Types::StopEventsDetectionJobResponse
Stops an events detection job in progress.
-
#stop_key_phrases_detection_job(params = {}) ⇒ Types::StopKeyPhrasesDetectionJobResponse
Stops a key phrases detection job in progress.
-
#stop_pii_entities_detection_job(params = {}) ⇒ Types::StopPiiEntitiesDetectionJobResponse
Stops a PII entities detection job in progress.
-
#stop_sentiment_detection_job(params = {}) ⇒ Types::StopSentimentDetectionJobResponse
Stops a sentiment detection job in progress.
-
#stop_targeted_sentiment_detection_job(params = {}) ⇒ Types::StopTargetedSentimentDetectionJobResponse
Stops a targeted sentiment detection job in progress.
-
#stop_training_document_classifier(params = {}) ⇒ Struct
Stops a document classifier training job while in progress.
-
#stop_training_entity_recognizer(params = {}) ⇒ Struct
Stops an entity recognizer training job while in progress.
-
#tag_resource(params = {}) ⇒ Struct
Associates a specific tag with an Amazon Comprehend resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a specific tag associated with an Amazon Comprehend resource.
-
#update_endpoint(params = {}) ⇒ Types::UpdateEndpointResponse
Updates information about the specified endpoint.
-
#update_flywheel(params = {}) ⇒ Types::UpdateFlywheelResponse
Update the configuration information for an existing flywheel.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-comprehend/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6016 6017 6018 |
# File 'lib/aws-sdk-comprehend/client.rb', line 6016 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6019 6020 6021 |
# File 'lib/aws-sdk-comprehend/client.rb', line 6019 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#batch_detect_dominant_language(params = {}) ⇒ Types::BatchDetectDominantLanguageResponse
Determines the dominant language of the input text for a batch of documents. For a list of languages that Amazon Comprehend can detect, see Amazon Comprehend Supported Languages.
88 |
# File 'sig/client.rbs', line 88 def batch_detect_dominant_language: ( |
#batch_detect_entities(params = {}) ⇒ Types::BatchDetectEntitiesResponse
Inspects the text of a batch of documents for named entities and returns information about them. For more information about named entities, see Entities in the Comprehend Developer Guide.
99 |
# File 'sig/client.rbs', line 99 def batch_detect_entities: ( |
#batch_detect_key_phrases(params = {}) ⇒ Types::BatchDetectKeyPhrasesResponse
Detects the key noun phrases found in a batch of documents.
111 |
# File 'sig/client.rbs', line 111 def batch_detect_key_phrases: ( |
#batch_detect_sentiment(params = {}) ⇒ Types::BatchDetectSentimentResponse
Inspects a batch of documents and returns an inference of the
prevailing sentiment, POSITIVE, NEUTRAL, MIXED, or NEGATIVE,
in each one.
123 |
# File 'sig/client.rbs', line 123 def batch_detect_sentiment: ( |
#batch_detect_syntax(params = {}) ⇒ Types::BatchDetectSyntaxResponse
Inspects the text of a batch of documents for the syntax and part of speech of the words in the document and returns information about them. For more information, see Syntax in the Comprehend Developer Guide.
135 |
# File 'sig/client.rbs', line 135 def batch_detect_syntax: ( |
#batch_detect_targeted_sentiment(params = {}) ⇒ Types::BatchDetectTargetedSentimentResponse
Inspects a batch of documents and returns a sentiment analysis for each entity identified in the documents.
For more information about targeted sentiment, see Targeted sentiment in the Amazon Comprehend Developer Guide.
147 |
# File 'sig/client.rbs', line 147 def batch_detect_targeted_sentiment: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 |
# File 'lib/aws-sdk-comprehend/client.rb', line 5989 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Comprehend') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-comprehend' context[:gem_version] = '1.119.0' Seahorse::Client::Request.new(handlers, context) end |
#classify_document(params = {}) ⇒ Types::ClassifyDocumentResponse
Creates a classification request to analyze a single document in
real-time. ClassifyDocument supports the following model types:
-
Custom classifier - a custom model that you have created and trained. For input, you can provide plain text, a single-page document (PDF, Word, or image), or Amazon Textract API output. For more information, see Custom classification in the Amazon Comprehend Developer Guide.
-
Prompt safety classifier - Amazon Comprehend provides a pre-trained model for classifying input prompts for generative AI applications. For input, you provide English plain text input. For prompt safety classification, the response includes only the
Classesfield. For more information about prompt safety classifiers, see Prompt safety classification in the Amazon Comprehend Developer Guide.
If the system detects errors while processing a page in the input
document, the API response includes an Errors field that describes
the errors.
If the system detects a document-level error in your input document,
the API returns an InvalidRequestException error response. For
details about this exception, see Errors in semi-structured
documents in the Comprehend Developer Guide.
163 |
# File 'sig/client.rbs', line 163 def classify_document: ( |
#contains_pii_entities(params = {}) ⇒ Types::ContainsPiiEntitiesResponse
Analyzes input text for the presence of personally identifiable information (PII) and returns the labels of identified PII entity types such as name, address, bank account number, or phone number.
180 |
# File 'sig/client.rbs', line 180 def contains_pii_entities: ( |
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a dataset to upload training or test data for a model associated with a flywheel. For more information about datasets, see Flywheel overview in the Amazon Comprehend Developer Guide.
191 |
# File 'sig/client.rbs', line 191 def create_dataset: ( |
#create_document_classifier(params = {}) ⇒ Types::CreateDocumentClassifierResponse
Creates a new document classifier that you can use to categorize documents. To create a classifier, you provide a set of training documents that are labeled with the categories that you want to use. For more information, see Training classifier models in the Comprehend Developer Guide.
239 |
# File 'sig/client.rbs', line 239 def create_document_classifier: ( |
#create_endpoint(params = {}) ⇒ Types::CreateEndpointResponse
Creates a model-specific endpoint for synchronous inference for a previously trained custom model For information about endpoints, see Managing endpoints.
292 |
# File 'sig/client.rbs', line 292 def create_endpoint: ( |
#create_entity_recognizer(params = {}) ⇒ Types::CreateEntityRecognizerResponse
Creates an entity recognizer using submitted files. After your
CreateEntityRecognizer request is submitted, you can check job
status using the DescribeEntityRecognizer API.
313 |
# File 'sig/client.rbs', line 313 def create_entity_recognizer: ( |
#create_flywheel(params = {}) ⇒ Types::CreateFlywheelResponse
A flywheel is an Amazon Web Services resource that orchestrates the ongoing training of a model for custom classification or custom entity recognition. You can create a flywheel to start with an existing trained model, or Comprehend can create and train a new model.
When you create the flywheel, Comprehend creates a data lake in your account. The data lake holds the training data and test data for all versions of the model.
To use a flywheel with an existing trained model, you specify the active model version. Comprehend copies the model's training data and test data into the flywheel's data lake.
To use the flywheel with a new model, you need to provide a dataset for training data (and optional test data) when you create the flywheel.
For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
364 |
# File 'sig/client.rbs', line 364 def create_flywheel: ( |
#delete_document_classifier(params = {}) ⇒ Struct
Deletes a previously created document classifier
Only those classifiers that are in terminated states (IN_ERROR,
TRAINED) will be deleted. If an active inference job is using the
model, a ResourceInUseException will be returned.
This is an asynchronous action that puts the classifier into a DELETING state, and it is then removed by a background job. Once removed, the classifier disappears from your account and is no longer available for use.
407 |
# File 'sig/client.rbs', line 407 def delete_document_classifier: ( |
#delete_endpoint(params = {}) ⇒ Struct
Deletes a model-specific endpoint for a previously-trained custom model. All endpoints must be deleted in order for the model to be deleted. For information about endpoints, see Managing endpoints.
416 |
# File 'sig/client.rbs', line 416 def delete_endpoint: ( |
#delete_entity_recognizer(params = {}) ⇒ Struct
Deletes an entity recognizer.
Only those recognizers that are in terminated states (IN_ERROR,
TRAINED) will be deleted. If an active inference job is using the
model, a ResourceInUseException will be returned.
This is an asynchronous action that puts the recognizer into a DELETING state, and it is then removed by a background job. Once removed, the recognizer disappears from your account and is no longer available for use.
425 |
# File 'sig/client.rbs', line 425 def delete_entity_recognizer: ( |
#delete_flywheel(params = {}) ⇒ Struct
Deletes a flywheel. When you delete the flywheel, Amazon Comprehend does not delete the data lake or the model associated with the flywheel.
For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
434 |
# File 'sig/client.rbs', line 434 def delete_flywheel: ( |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy that is attached to a custom model.
443 |
# File 'sig/client.rbs', line 443 def delete_resource_policy: ( |
#describe_dataset(params = {}) ⇒ Types::DescribeDatasetResponse
Returns information about the dataset that you specify. For more information about datasets, see Flywheel overview in the Amazon Comprehend Developer Guide.
454 |
# File 'sig/client.rbs', line 454 def describe_dataset: ( |
#describe_document_classification_job(params = {}) ⇒ Types::DescribeDocumentClassificationJobResponse
Gets the properties associated with a document classification job. Use this operation to get the status of a classification job.
464 |
# File 'sig/client.rbs', line 464 def describe_document_classification_job: ( |
#describe_document_classifier(params = {}) ⇒ Types::DescribeDocumentClassifierResponse
Gets the properties associated with a document classifier.
474 |
# File 'sig/client.rbs', line 474 def describe_document_classifier: ( |
#describe_dominant_language_detection_job(params = {}) ⇒ Types::DescribeDominantLanguageDetectionJobResponse
Gets the properties associated with a dominant language detection job. Use this operation to get the status of a detection job.
484 |
# File 'sig/client.rbs', line 484 def describe_dominant_language_detection_job: ( |
#describe_endpoint(params = {}) ⇒ Types::DescribeEndpointResponse
Gets the properties associated with a specific endpoint. Use this operation to get the status of an endpoint. For information about endpoints, see Managing endpoints.
494 |
# File 'sig/client.rbs', line 494 def describe_endpoint: ( |
#describe_entities_detection_job(params = {}) ⇒ Types::DescribeEntitiesDetectionJobResponse
Gets the properties associated with an entities detection job. Use this operation to get the status of a detection job.
504 |
# File 'sig/client.rbs', line 504 def describe_entities_detection_job: ( |
#describe_entity_recognizer(params = {}) ⇒ Types::DescribeEntityRecognizerResponse
Provides details about an entity recognizer including status, S3 buckets containing training data, recognizer metadata, metrics, and so on.
514 |
# File 'sig/client.rbs', line 514 def describe_entity_recognizer: ( |
#describe_events_detection_job(params = {}) ⇒ Types::DescribeEventsDetectionJobResponse
Gets the status and details of an events detection job.
524 |
# File 'sig/client.rbs', line 524 def describe_events_detection_job: ( |
#describe_flywheel(params = {}) ⇒ Types::DescribeFlywheelResponse
Provides configuration information about the flywheel. For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
534 |
# File 'sig/client.rbs', line 534 def describe_flywheel: ( |
#describe_flywheel_iteration(params = {}) ⇒ Types::DescribeFlywheelIterationResponse
Retrieve the configuration properties of a flywheel iteration. For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
544 |
# File 'sig/client.rbs', line 544 def describe_flywheel_iteration: ( |
#describe_key_phrases_detection_job(params = {}) ⇒ Types::DescribeKeyPhrasesDetectionJobResponse
Gets the properties associated with a key phrases detection job. Use this operation to get the status of a detection job.
555 |
# File 'sig/client.rbs', line 555 def describe_key_phrases_detection_job: ( |
#describe_pii_entities_detection_job(params = {}) ⇒ Types::DescribePiiEntitiesDetectionJobResponse
Gets the properties associated with a PII entities detection job. For example, you can use this operation to get the job status.
565 |
# File 'sig/client.rbs', line 565 def describe_pii_entities_detection_job: ( |
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Gets the details of a resource-based policy that is attached to a custom model, including the JSON body of the policy.
578 |
# File 'sig/client.rbs', line 578 def describe_resource_policy: ( |
#describe_sentiment_detection_job(params = {}) ⇒ Types::DescribeSentimentDetectionJobResponse
Gets the properties associated with a sentiment detection job. Use this operation to get the status of a detection job.
588 |
# File 'sig/client.rbs', line 588 def describe_sentiment_detection_job: ( |
#describe_targeted_sentiment_detection_job(params = {}) ⇒ Types::DescribeTargetedSentimentDetectionJobResponse
Gets the properties associated with a targeted sentiment detection job. Use this operation to get the status of the job.
598 |
# File 'sig/client.rbs', line 598 def describe_targeted_sentiment_detection_job: ( |
#describe_topics_detection_job(params = {}) ⇒ Types::DescribeTopicsDetectionJobResponse
Gets the properties associated with a topic detection job. Use this operation to get the status of a detection job.
608 |
# File 'sig/client.rbs', line 608 def describe_topics_detection_job: ( |
#detect_dominant_language(params = {}) ⇒ Types::DetectDominantLanguageResponse
Determines the dominant language of the input text. For a list of languages that Amazon Comprehend can detect, see Amazon Comprehend Supported Languages.
618 |
# File 'sig/client.rbs', line 618 def detect_dominant_language: ( |
#detect_entities(params = {}) ⇒ Types::DetectEntitiesResponse
Detects named entities in input text when you use the pre-trained model. Detects custom entities if you have a custom entity recognition model.
When detecting named entities using the pre-trained model, use plain text as the input. For more information about named entities, see Entities in the Comprehend Developer Guide.
When you use a custom entity recognition model, you can input plain text or you can upload a single-page input document (text, PDF, Word, or image).
If the system detects errors while processing a page in the input
document, the API response includes an entry in Errors for each
error.
If the system detects a document-level error in your input document,
the API returns an InvalidRequestException error response. For
details about this exception, see Errors in semi-structured
documents in the Comprehend Developer Guide.
632 |
# File 'sig/client.rbs', line 632 def detect_entities: ( |
#detect_key_phrases(params = {}) ⇒ Types::DetectKeyPhrasesResponse
Detects the key noun phrases found in the text.
650 |
# File 'sig/client.rbs', line 650 def detect_key_phrases: ( |
#detect_pii_entities(params = {}) ⇒ Types::DetectPiiEntitiesResponse
Inspects the input text for entities that contain personally identifiable information (PII) and returns information about them.
661 |
# File 'sig/client.rbs', line 661 def detect_pii_entities: ( |
#detect_sentiment(params = {}) ⇒ Types::DetectSentimentResponse
Inspects text and returns an inference of the prevailing sentiment
(POSITIVE, NEUTRAL, MIXED, or NEGATIVE).
673 |
# File 'sig/client.rbs', line 673 def detect_sentiment: ( |
#detect_syntax(params = {}) ⇒ Types::DetectSyntaxResponse
Inspects text for syntax and the part of speech of words in the document. For more information, see Syntax in the Comprehend Developer Guide.
684 |
# File 'sig/client.rbs', line 684 def detect_syntax: ( |
#detect_targeted_sentiment(params = {}) ⇒ Types::DetectTargetedSentimentResponse
Inspects the input text and returns a sentiment analysis for each entity identified in the text.
For more information about targeted sentiment, see Targeted sentiment in the Amazon Comprehend Developer Guide.
695 |
# File 'sig/client.rbs', line 695 def detect_targeted_sentiment: ( |
#detect_toxic_content(params = {}) ⇒ Types::DetectToxicContentResponse
Performs toxicity analysis on the list of text strings that you provide as input. The API response contains a results list that matches the size of the input list. For more information about toxicity detection, see Toxicity detection in the Amazon Comprehend Developer Guide.
706 |
# File 'sig/client.rbs', line 706 def detect_toxic_content: ( |
#import_model(params = {}) ⇒ Types::ImportModelResponse
Creates a new custom model that replicates a source custom model that you import. The source model can be in your Amazon Web Services account or another one.
If the source model is in another Amazon Web Services account, then it must have a resource-based policy that authorizes you to import it.
The source model must be in the same Amazon Web Services Region that you're using when you import. You can't import a model that's in a different Region.
721 |
# File 'sig/client.rbs', line 721 def import_model: ( |
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
List the datasets that you have configured in this Region. For more information about datasets, see Flywheel overview in the Amazon Comprehend Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
742 |
# File 'sig/client.rbs', line 742 def list_datasets: ( |
#list_document_classification_jobs(params = {}) ⇒ Types::ListDocumentClassificationJobsResponse
Gets a list of the documentation classification jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
761 |
# File 'sig/client.rbs', line 761 def list_document_classification_jobs: ( |
#list_document_classifier_summaries(params = {}) ⇒ Types::ListDocumentClassifierSummariesResponse
Gets a list of summaries of the document classifiers that you have created
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
779 |
# File 'sig/client.rbs', line 779 def list_document_classifier_summaries: ( |
#list_document_classifiers(params = {}) ⇒ Types::ListDocumentClassifiersResponse
Gets a list of the document classifiers that you have created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
791 |
# File 'sig/client.rbs', line 791 def list_document_classifiers: ( |
#list_dominant_language_detection_jobs(params = {}) ⇒ Types::ListDominantLanguageDetectionJobsResponse
Gets a list of the dominant language detection jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
809 |
# File 'sig/client.rbs', line 809 def list_dominant_language_detection_jobs: ( |
#list_endpoints(params = {}) ⇒ Types::ListEndpointsResponse
Gets a list of all existing endpoints that you've created. For information about endpoints, see Managing endpoints.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
827 |
# File 'sig/client.rbs', line 827 def list_endpoints: ( |
#list_entities_detection_jobs(params = {}) ⇒ Types::ListEntitiesDetectionJobsResponse
Gets a list of the entity detection jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
845 |
# File 'sig/client.rbs', line 845 def list_entities_detection_jobs: ( |
#list_entity_recognizer_summaries(params = {}) ⇒ Types::ListEntityRecognizerSummariesResponse
Gets a list of summaries for the entity recognizers that you have created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
863 |
# File 'sig/client.rbs', line 863 def list_entity_recognizer_summaries: ( |
#list_entity_recognizers(params = {}) ⇒ Types::ListEntityRecognizersResponse
Gets a list of the properties of all entity recognizers that you created, including recognizers currently in training. Allows you to filter the list of recognizers based on criteria such as status and submission time. This call returns up to 500 entity recognizers in the list, with a default number of 100 recognizers in the list.
The results of this list are not in any particular order. Please get the list and sort locally if needed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
875 |
# File 'sig/client.rbs', line 875 def list_entity_recognizers: ( |
#list_events_detection_jobs(params = {}) ⇒ Types::ListEventsDetectionJobsResponse
Gets a list of the events detection jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
893 |
# File 'sig/client.rbs', line 893 def list_events_detection_jobs: ( |
#list_flywheel_iteration_history(params = {}) ⇒ Types::ListFlywheelIterationHistoryResponse
Information about the history of a flywheel iteration. For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
911 |
# File 'sig/client.rbs', line 911 def list_flywheel_iteration_history: ( |
#list_flywheels(params = {}) ⇒ Types::ListFlywheelsResponse
Gets a list of the flywheels that you have created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
928 |
# File 'sig/client.rbs', line 928 def list_flywheels: ( |
#list_key_phrases_detection_jobs(params = {}) ⇒ Types::ListKeyPhrasesDetectionJobsResponse
Get a list of key phrase detection jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
945 |
# File 'sig/client.rbs', line 945 def list_key_phrases_detection_jobs: ( |
#list_pii_entities_detection_jobs(params = {}) ⇒ Types::ListPiiEntitiesDetectionJobsResponse
Gets a list of the PII entity detection jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
963 |
# File 'sig/client.rbs', line 963 def list_pii_entities_detection_jobs: ( |
#list_sentiment_detection_jobs(params = {}) ⇒ Types::ListSentimentDetectionJobsResponse
Gets a list of sentiment detection jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
981 |
# File 'sig/client.rbs', line 981 def list_sentiment_detection_jobs: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a given Amazon Comprehend resource.
999 |
# File 'sig/client.rbs', line 999 def list_tags_for_resource: ( |
#list_targeted_sentiment_detection_jobs(params = {}) ⇒ Types::ListTargetedSentimentDetectionJobsResponse
Gets a list of targeted sentiment detection jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1010 |
# File 'sig/client.rbs', line 1010 def list_targeted_sentiment_detection_jobs: ( |
#list_topics_detection_jobs(params = {}) ⇒ Types::ListTopicsDetectionJobsResponse
Gets a list of the topic detection jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1028 |
# File 'sig/client.rbs', line 1028 def list_topics_detection_jobs: ( |
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Attaches a resource-based policy to a custom model. You can use this policy to authorize an entity in another Amazon Web Services account to import the custom model, which replicates it in Amazon Comprehend in their account.
1045 |
# File 'sig/client.rbs', line 1045 def put_resource_policy: ( |
#start_document_classification_job(params = {}) ⇒ Types::StartDocumentClassificationJobResponse
Starts an asynchronous document classification job using a custom
classification model. Use the DescribeDocumentClassificationJob
operation to track the progress of the job.
1060 |
# File 'sig/client.rbs', line 1060 def start_document_classification_job: ( |
#start_dominant_language_detection_job(params = {}) ⇒ Types::StartDominantLanguageDetectionJobResponse
Starts an asynchronous dominant language detection job for a collection of documents. Use the operation to track the status of a job.
1092 |
# File 'sig/client.rbs', line 1092 def start_dominant_language_detection_job: ( |
#start_entities_detection_job(params = {}) ⇒ Types::StartEntitiesDetectionJobResponse
Starts an asynchronous entity detection job for a collection of documents. Use the operation to track the status of a job.
This API can be used for either standard entity detection or custom
entity recognition. In order to be used for custom entity recognition,
the optional EntityRecognizerArn must be used in order to provide
access to the recognizer being used to detect the custom entity.
1123 |
# File 'sig/client.rbs', line 1123 def start_entities_detection_job: ( |
#start_events_detection_job(params = {}) ⇒ Types::StartEventsDetectionJobResponse
Starts an asynchronous event detection job for a collection of documents.
1156 |
# File 'sig/client.rbs', line 1156 def start_events_detection_job: ( |
#start_flywheel_iteration(params = {}) ⇒ Types::StartFlywheelIterationResponse
Start the flywheel iteration.This operation uses any new datasets to train a new model version. For more information about flywheels, see Flywheel overview in the Amazon Comprehend Developer Guide.
1182 |
# File 'sig/client.rbs', line 1182 def start_flywheel_iteration: ( |
#start_key_phrases_detection_job(params = {}) ⇒ Types::StartKeyPhrasesDetectionJobResponse
Starts an asynchronous key phrase detection job for a collection of documents. Use the operation to track the status of a job.
1195 |
# File 'sig/client.rbs', line 1195 def start_key_phrases_detection_job: ( |
#start_pii_entities_detection_job(params = {}) ⇒ Types::StartPiiEntitiesDetectionJobResponse
Starts an asynchronous PII entity detection job for a collection of documents.
1226 |
# File 'sig/client.rbs', line 1226 def start_pii_entities_detection_job: ( |
#start_sentiment_detection_job(params = {}) ⇒ Types::StartSentimentDetectionJobResponse
Starts an asynchronous sentiment detection job for a collection of documents. Use the operation to track the status of a job.
1258 |
# File 'sig/client.rbs', line 1258 def start_sentiment_detection_job: ( |
#start_targeted_sentiment_detection_job(params = {}) ⇒ Types::StartTargetedSentimentDetectionJobResponse
Starts an asynchronous targeted sentiment detection job for a
collection of documents. Use the
DescribeTargetedSentimentDetectionJob operation to track the status
of a job.
1289 |
# File 'sig/client.rbs', line 1289 def start_targeted_sentiment_detection_job: ( |
#start_topics_detection_job(params = {}) ⇒ Types::StartTopicsDetectionJobResponse
Starts an asynchronous topic detection job. Use the
DescribeTopicDetectionJob operation to track the status of a job.
1320 |
# File 'sig/client.rbs', line 1320 def start_topics_detection_job: ( |
#stop_dominant_language_detection_job(params = {}) ⇒ Types::StopDominantLanguageDetectionJobResponse
Stops a dominant language detection job in progress.
If the job state is IN_PROGRESS the job is marked for termination
and put into the STOP_REQUESTED state. If the job completes before
it can be stopped, it is put into the COMPLETED state; otherwise the
job is stopped and put into the STOPPED state.
If the job is in the COMPLETED or FAILED state when you call the
StopDominantLanguageDetectionJob operation, the operation returns a
400 Internal Request Exception.
When a job is stopped, any documents already processed are written to the output location.
1350 |
# File 'sig/client.rbs', line 1350 def stop_dominant_language_detection_job: ( |
#stop_entities_detection_job(params = {}) ⇒ Types::StopEntitiesDetectionJobResponse
Stops an entities detection job in progress.
If the job state is IN_PROGRESS the job is marked for termination
and put into the STOP_REQUESTED state. If the job completes before
it can be stopped, it is put into the COMPLETED state; otherwise the
job is stopped and put into the STOPPED state.
If the job is in the COMPLETED or FAILED state when you call the
StopDominantLanguageDetectionJob operation, the operation returns a
400 Internal Request Exception.
When a job is stopped, any documents already processed are written to the output location.
1361 |
# File 'sig/client.rbs', line 1361 def stop_entities_detection_job: ( |
#stop_events_detection_job(params = {}) ⇒ Types::StopEventsDetectionJobResponse
Stops an events detection job in progress.
1372 |
# File 'sig/client.rbs', line 1372 def stop_events_detection_job: ( |
#stop_key_phrases_detection_job(params = {}) ⇒ Types::StopKeyPhrasesDetectionJobResponse
Stops a key phrases detection job in progress.
If the job state is IN_PROGRESS the job is marked for termination
and put into the STOP_REQUESTED state. If the job completes before
it can be stopped, it is put into the COMPLETED state; otherwise the
job is stopped and put into the STOPPED state.
If the job is in the COMPLETED or FAILED state when you call the
StopDominantLanguageDetectionJob operation, the operation returns a
400 Internal Request Exception.
When a job is stopped, any documents already processed are written to the output location.
1383 |
# File 'sig/client.rbs', line 1383 def stop_key_phrases_detection_job: ( |
#stop_pii_entities_detection_job(params = {}) ⇒ Types::StopPiiEntitiesDetectionJobResponse
Stops a PII entities detection job in progress.
1394 |
# File 'sig/client.rbs', line 1394 def stop_pii_entities_detection_job: ( |
#stop_sentiment_detection_job(params = {}) ⇒ Types::StopSentimentDetectionJobResponse
Stops a sentiment detection job in progress.
If the job state is IN_PROGRESS, the job is marked for termination
and put into the STOP_REQUESTED state. If the job completes before
it can be stopped, it is put into the COMPLETED state; otherwise the
job is be stopped and put into the STOPPED state.
If the job is in the COMPLETED or FAILED state when you call the
StopDominantLanguageDetectionJob operation, the operation returns a
400 Internal Request Exception.
When a job is stopped, any documents already processed are written to the output location.
1405 |
# File 'sig/client.rbs', line 1405 def stop_sentiment_detection_job: ( |
#stop_targeted_sentiment_detection_job(params = {}) ⇒ Types::StopTargetedSentimentDetectionJobResponse
Stops a targeted sentiment detection job in progress.
If the job state is IN_PROGRESS, the job is marked for termination
and put into the STOP_REQUESTED state. If the job completes before
it can be stopped, it is put into the COMPLETED state; otherwise the
job is be stopped and put into the STOPPED state.
If the job is in the COMPLETED or FAILED state when you call the
StopDominantLanguageDetectionJob operation, the operation returns a
400 Internal Request Exception.
When a job is stopped, any documents already processed are written to the output location.
1416 |
# File 'sig/client.rbs', line 1416 def stop_targeted_sentiment_detection_job: ( |
#stop_training_document_classifier(params = {}) ⇒ Struct
Stops a document classifier training job while in progress.
If the training job state is TRAINING, the job is marked for
termination and put into the STOP_REQUESTED state. If the training
job completes before it can be stopped, it is put into the TRAINED;
otherwise the training job is stopped and put into the STOPPED state
and the service sends back an HTTP 200 response with an empty HTTP
body.
1425 |
# File 'sig/client.rbs', line 1425 def stop_training_document_classifier: ( |
#stop_training_entity_recognizer(params = {}) ⇒ Struct
Stops an entity recognizer training job while in progress.
If the training job state is TRAINING, the job is marked for
termination and put into the STOP_REQUESTED state. If the training
job completes before it can be stopped, it is put into the TRAINED;
otherwise the training job is stopped and putted into the STOPPED
state and the service sends back an HTTP 200 response with an empty
HTTP body.
1434 |
# File 'sig/client.rbs', line 1434 def stop_training_entity_recognizer: ( |
#tag_resource(params = {}) ⇒ Struct
Associates a specific tag with an Amazon Comprehend resource. A tag is a key-value pair that adds as a metadata to a resource used by Amazon Comprehend. For example, a tag with "Sales" as the key might be added to a resource to indicate its use by the sales department.
1443 |
# File 'sig/client.rbs', line 1443 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Removes a specific tag associated with an Amazon Comprehend resource.
1458 |
# File 'sig/client.rbs', line 1458 def untag_resource: ( |
#update_endpoint(params = {}) ⇒ Types::UpdateEndpointResponse
Updates information about the specified endpoint. For information about endpoints, see Managing endpoints.
1469 |
# File 'sig/client.rbs', line 1469 def update_endpoint: ( |
#update_flywheel(params = {}) ⇒ Types::UpdateFlywheelResponse
Update the configuration information for an existing flywheel.
1483 |
# File 'sig/client.rbs', line 1483 def update_flywheel: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6009 6010 6011 |
# File 'lib/aws-sdk-comprehend/client.rb', line 6009 def waiter_names [] end |