Class: Aws::Comprehend::Types::BatchDetectTargetedSentimentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Comprehend::Types::BatchDetectTargetedSentimentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-comprehend/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_list ⇒ Array<Types::BatchItemError>
List of errors that the operation can return.
-
#result_list ⇒ Array<Types::BatchDetectTargetedSentimentItemResult>
A list of objects containing the results of the operation.
Instance Attribute Details
#error_list ⇒ Array<Types::BatchItemError>
List of errors that the operation can return.
466 467 468 469 470 471 |
# File 'lib/aws-sdk-comprehend/types.rb', line 466 class BatchDetectTargetedSentimentResponse < Struct.new( :result_list, :error_list) SENSITIVE = [] include Aws::Structure end |
#result_list ⇒ Array<Types::BatchDetectTargetedSentimentItemResult>
A list of objects containing the results of the operation. The results are sorted in ascending order by the Index field and match the order of the documents in the input list. If all of the documents contain an error, the ResultList is empty.
466 467 468 469 470 471 |
# File 'lib/aws-sdk-comprehend/types.rb', line 466 class BatchDetectTargetedSentimentResponse < Struct.new( :result_list, :error_list) SENSITIVE = [] include Aws::Structure end |